#
# spec file for package patchutils
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           patchutils
Version:        0.4.2
Release:        1.11
Summary:        A Collection of Tools for Manipulating Patch Files
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            http://cyberelk.net/tim/software/patchutils/
Source0:        http://cyberelk.net/tim/data/patchutils/stable/%{name}-%{version}.tar.xz
Source1:        http://cyberelk.net/tim/data/patchutils/stable/%{name}-%{version}.tar.xz.sig
Patch2:         rediff-hunk-init-fix.diff
BuildRequires:  automake
Requires:       diffutils
Requires:       patch

%description
Patchutils contains a collection of tools for manipulating patch files:
interdiff, combinediff, filterdiff, fixcvsdiff, rediff, lsdiff, and
splitdiff. You can use interdiff to create an incremental patch between
two patches that are against a common source tree. Combinediff can be
used for creating a cumulative diff from two incremental patches.
Filterdiff is for extracting or excluding patches from a patch set
based on modified files matching shell wildcards. Lsdiff lists modified
files in a patch. Rediff corrects hand-edited patches.

%prep
%autosetup -p1

%build
%configure
%make_build

%check
%make_build --jobs=1 check

%install
%make_install
install -m 0755 -d %{buildroot}%{_mandir}/man1/
install -m 0644 -t %{buildroot}%{_mandir}/man1/ doc/*.1

%files
%license COPYING
%doc BUGS README
%{_bindir}/combinediff
%{_bindir}/dehtmldiff
%{_bindir}/editdiff
%{_bindir}/espdiff
%{_bindir}/filterdiff
%{_bindir}/fixcvsdiff
%{_bindir}/flipdiff
%{_bindir}/gitdiff
%{_bindir}/gitdiffview
%{_bindir}/grepdiff
%{_bindir}/interdiff
%{_bindir}/lsdiff
%{_bindir}/patchview
%{_bindir}/recountdiff
%{_bindir}/rediff
%{_bindir}/splitdiff
%exclude %{_bindir}/svndiff
%exclude %{_bindir}/svndiffview
%{_bindir}/unwrapdiff
%{_mandir}/man1/*.1%{?ext_man}

%changelog
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.2:
  * Fixed a packaging issue
  * New patchview mode with accompanying scripts.
  * New grepdiff option --only-match.
  * New filterdiff option --remove-timestamps.
  * Assorted other fixes and improvements.
- remove patchutils-0.2.30-tailsyntax.diff: obsolete
- skip svndiff tools as those conflict with subversion
* Mon Dec 16 2019 Martin Pluskal <mpluskal@suse.com>
- Drop xmlto dependency as it would introduce build cycle
* Thu Dec 12 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Fri Jul  3 2015 sleep_walker@opensuse.org
- Update to 0.3.4
  * Some fixes for filterdiff and rediff.
  * The splitdiff utility now has an option to write output to a
    subdirectory.
  * Ranges can now be prefixed by a modifier ('x') to exclude spans
    instead of include them.
  * Extended headers produced by git are now handled by filterdiff
    and interdiff.
- remove overrun.diff (upstream has the fix already)
- remove autoconf part from spec file as tarball is generated with
  new enough versions
- install man pages manually
- add signature file
* Fri Aug 29 2014 asterios.dramis@gmail.com
- Update to 0.3.3:
  * Context output format for "no newline" lines has been fixed.
  * The splitdiff utility now has an option to disable ".patch"
    filename extensions.
  * Some fixes for bugs spotted by Coverity.
  * Interdiff can now use "-" (stdin) for one of the inputs.
- Run "make check" in %%check section.
* Sat Mar  9 2013 seife+obs@b1-systems.com
- fix build with autmake-1.13, convert changes to utf-8
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Apr  4 2011 sndirsch@novell.com
- added patch and diffutils to requires (bnc #662957)
* Thu Feb 10 2011 pascal.bleser@opensuse.org
- update to 0.3.2:
  * interdiff had previously been putting absolute filenames in the input to
    the patch program; it now avoids doing this
  * editdiff no longer runs rediff when no changes were made in the editor
  * the correct exit status is now set when the decompress option fails
  * a temporary file leak has been fixed
* Mon Apr 19 2010 sndirsch@suse.de
- rediff-hunk-init-fix.diff (Takashi Iwai)
  * hunk structure wasn't correctly initialized; fixes
    tests/addhunk2 testcase, which broke the build
* Wed Jan  6 2010 jengelh@medozas.de
- enable parallel build
* Sat Jan 24 2009 sndirsch@suse.de
- patchutils 0.3.1
  * new release
* Fri Jul  4 2008 sndirsch@suse.de
- patchutils 0.3.0
  * new release
* Fri Mar 16 2007 dmueller@suse.de
- fix rediff to actually work
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 mmj@suse.de
- Update to 0.2.31 which fixes severeal small bugs
* Wed Aug 11 2004 mmj@suse.de
- Update to 0.2.30 where some minor parsing bugs were fixed,
  the documentation was clarified, and a new option was added to
  lsdiff/filterdiff for selecting patches based on the order in
  which they appear.
* Tue Jul  6 2004 mmj@suse.de
- Update to 0.2.29 including since 0.2.27:
  o Some format conversion bugs were fixed.
  o Fix no-newline handling
  o Generate context format that GNU patch actually understands.
* Tue Mar  2 2004 mmj@suse.de
- Update to 0.2.27 including since 0.2.22:
  o An option was added to lsdiff to treating empty files as
  absent.
  o The filterdiff and interdiff utilities now handle patches
  containing embedded null characters.
  o The dehtmldiff utility was improved slightly.
  o A new filterdiff option for displaying patch filenames.
  o A new splitdiff option to make it behave more like diffsplit.
  o A new filterdiff option for removing timestamps.
  o New grepdiff options -E and -f.
  o Minor bugfixes
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Mon Apr  7 2003 ro@suse.de
- fix tail calling syntax in testsuite
* Wed Mar 26 2003 mmj@suse.de
- Update to 0.2.22:, including the following since 0.2.17:
  · New splitdiff option to split out every file-level patch, and
    a new option was added to grepdiff to display matching hunks
  · A new tool was added for exchanging the order of two patches
  · Support for ISO 8601 timezones
  · Several bug fixes
  · Our patches are in mainline
* Mon Mar  3 2003 pthomas@suse.de
- Use execvp in rediff, fixes #22428.
- Fix configure.in for automake 1.6.
* Tue Sep 17 2002 uli@suse.de
- update -> 0.2.17 (support for conversion between unified and
  context formats, new option (--annotate) added to filterdiff,
  interdiff can now strip context lines from patches, recountdiff
  and unwrapdiff tools added)
* Thu Jun 13 2002 uli@suse.de
- update -> 0.2.14 (hunk-level filtering was added to filterdiff)
* Fri May 10 2002 uli@suse.de
- update -> 0.2.13
* Fri Apr 19 2002 uli@suse.de
- fixed the fix
* Fri Apr 19 2002 uli@suse.de
- update -> 0.2.12pre1
- added support for different date formats
* Fri Feb  1 2002 uli@suse.de
- update -> 0.2.8 (adds grepdiff, bugfixes)
* Tue Dec  4 2001 uli@suse.de
- update -> 0.2.5 (bugs in lsdiff and combinediff fixed)
* Wed Nov 28 2001 uli@suse.de
- initial package
